@@ -194,6 +194,8 @@ checkAndFixCohortDefinitionSetDataTypes <- function(x, fixDataTypes = TRUE, emit
 #'
 #' @param sqlFolder        The name of the folder that will hold the SQL representation
 #'                         of the cohort.
+#' @param templateFolder  Defines the folder to store sql template cohorts that can be loaded as part of the definition
+#'                        JSON files are loaded into cohort definition set
 #'
 #' @param cohortFileNameFormat  Defines the format string  for naming the cohort
 #'                              JSON and SQL files. The format string follows the
@@ -221,6 +223,7 @@ getCohortDefinitionSet <- function(settingsFileName = "Cohorts.csv",
                                    cohortFileNameFormat = "%s",
                                    cohortFileNameValue = c("cohortId"),
                                    subsetJsonFolder = "inst/cohort_subset_definitions/",
+                                   templateFolder = "inst/cohort_template_definitions/",
                                    packageName = NULL,
                                    warnOnMissingJson = TRUE,
                                    verbose = FALSE) {
@@ -299,6 +302,8 @@ getCohortDefinitionSet <- function(settingsFileName = "Cohorts.csv",
   }
 
   cohortDefinitionSet <- cbind(settings, fileData)
+  cohortDefinitionSet <- loadTemplateDefinitionsFolder(cohortDefinitionSet, templateFolder)
+
   # Loading cohort subset definitions with their associated targets
   if (loadSubsets & nrow(subsetsToLoad) > 0) {
     if (dir.exists(subsetJsonFolder)) {
@@ -355,6 +360,8 @@ getCohortDefinitionSet <- function(settingsFileName = "Cohorts.csv",
 #'                              in conjunction with the cohortFileNameFormat parameter.
 #'
 #' @param subsetJsonFolder      Defines the folder to store the subset JSON
+#' @param templateFolder     Defines the folder to store sql template cohorts that can be saved as part of the definition
+#'                              Sql will be copied to this location when `saveCohortDefinitionSet` is called.
 #'
 #' @param verbose           When TRUE, logging messages are emitted to indicate export
 #'                          progress.
@@ -367,12 +374,25 @@ saveCohortDefinitionSet <- function(cohortDefinitionSet,
                                     cohortFileNameFormat = "%s",
                                     cohortFileNameValue = c("cohortId"),
                                     subsetJsonFolder = "inst/cohort_subset_definitions/",
+                                    templateFolder = "inst/cohort_template_definitions/",
                                     verbose = FALSE) {
   checkmate::assertDataFrame(cohortDefinitionSet, min.rows = 1, col.names = "named")
   checkmate::assert_vector(cohortFileNameValue)
   checkmate::assert_true(length(cohortFileNameValue) > 0)
   assertSettingsColumns(names(cohortDefinitionSet))
   checkmate::assert_true(all(cohortFileNameValue %in% names(cohortDefinitionSet)))
+
+  templateDefinitions <- getTemplateDefinitions(cohortDefinitionSet)
+  if (length(templateDefinitions) > 0) {
+    saveCohortTemplateDefinitions(templateDefinitions, templateFolder)
+    if (all(cohortDefinitionSet$isTemplatedCohort)) {
+      return(invisible())
+    }
+    # Don't save templates as regular cohorts
+    cohortDefinitionSet <- cohortDefinitionSet |>
+      dplyr::filter(!.data$isTemplatedCohort)
+  }
+
   settingsFolder <- dirname(settingsFileName)
   if (!dir.exists(settingsFolder)) {
     dir.create(settingsFolder, recursive = TRUE)
