@@ -35,6 +35,7 @@
 #'                                     inclusion rule statistics.
 #' @param cohortCensorStatsTable       Name of the censor stats table, one of the tables for storing
 #'                                     inclusion rule statistics.
+#' @param cohortChecksumTable          Stores the checksum of the cohort used and the time generation starts and ends
 #'
 #' @returns
 #' A list of the table names as specified in the parameters to this function.
@@ -46,7 +47,8 @@ getCohortTableNames <- function(cohortTable = "cohort",
                                 cohortInclusionResultTable = paste0(cohortTable, "_inclusion_result"),
                                 cohortInclusionStatsTable = paste0(cohortTable, "_inclusion_stats"),
                                 cohortSummaryStatsTable = paste0(cohortTable, "_summary_stats"),
-                                cohortCensorStatsTable = paste0(cohortTable, "_censor_stats")) {
+                                cohortCensorStatsTable = paste0(cohortTable, "_censor_stats"),
+                                cohortChecksumTable = paste0(cohortTable, "_checksum")) {
   return(list(
     cohortTable = cohortTable,
     cohortSampleTable = cohortSampleTable,
@@ -54,7 +56,8 @@ getCohortTableNames <- function(cohortTable = "cohort",
     cohortInclusionResultTable = cohortInclusionResultTable,
     cohortInclusionStatsTable = cohortInclusionStatsTable,
     cohortSummaryStatsTable = cohortSummaryStatsTable,
-    cohortCensorStatsTable = cohortCensorStatsTable
+    cohortCensorStatsTable = cohortCensorStatsTable,
+    cohortChecksumTable = cohortChecksumTable
   ))
 }
 
@@ -121,6 +124,7 @@ createCohortTables <- function(connectionDetails = NULL,
       create_cohort_inclusion_stats_table = createTableFlagList$cohortInclusionStatsTable,
       create_cohort_summary_stats_table = createTableFlagList$cohortSummaryStatsTable,
       create_cohort_censor_stats_table = createTableFlagList$cohortCensorStatsTable,
+      create_cohort_checksum_table = createTableFlagList$cohortChecksumTable,
       cohort_table = cohortTableNames$cohortTable,
       cohort_sample_table = cohortTableNames$cohortSampleTable,
       cohort_inclusion_table = cohortTableNames$cohortInclusionTable,
@@ -128,6 +132,7 @@ createCohortTables <- function(connectionDetails = NULL,
       cohort_inclusion_stats_table = cohortTableNames$cohortInclusionStatsTable,
       cohort_summary_stats_table = cohortTableNames$cohortSummaryStatsTable,
       cohort_censor_stats_table = cohortTableNames$cohortCensorStatsTable,
+      cohort_checksum_table = cohortTableNames$cohortChecksumTable,
       warnOnMissingParameters = TRUE
     )
     sql <- SqlRender::translate(
