@@ -41,7 +41,7 @@
 #' @param fileNamesInSnakeCase        Should the exported files use snake_case? Default is FALSE
 #'
 #' @param incremental                 If \code{incremental = TRUE}, results are written to update values instead of
-#'                                    overwriting an existing results
+#'                                    overwriting an existing results (deprecated)
 #'
 #' @param databaseId                  Optional - when specified, the databaseId will be added
 #'                                    to the exported results
@@ -94,24 +94,7 @@ exportCohortStatsTables <- function(connectionDetails,
       }
     }
 
-    if (incremental) {
-      # Dynamically build the arguments to the saveIncremental
-      # to specify the primary key(s) for the file
-      args <- list(
-        data = data,
-        file = fullFileName
-      )
-      for (i in seq_along(primaryKeyColumns)) {
-        colName <- ifelse(isTRUE(snakeCaseToCamelCase), yes = primaryKeyColumns[i], no = SqlRender::camelCaseToSnakeCase(primaryKeyColumns[i]))
-        args[[colName]] <- data[[colName]]
-      }
-      do.call(
-        what = CohortGenerator::saveIncremental,
-        args = args
-      )
-    } else {
-      .writeCsv(x = data, file = fullFileName)
-    }
+    .writeCsv(x = data, file = fullFileName)
   }
 
   tablesToExport <- data.frame(
@@ -162,14 +145,56 @@ exportCohortStatsTables <- function(connectionDetails,
   }
 }
 
+
+addSubsetColumns <- function(cohortDefinitionSet) {
+  if (nrow(cohortDefinitionSet) > 0 & !hasSubsetDefinitions(cohortDefinitionSet)) {
+    cohortDefinitionSet$isSubset <- 0
+    cohortDefinitionSet$subsetDefinitionId <- NA
+    cohortDefinitionSet$subsetParent <- cohortDefinitionSet$cohortId
+  }
+
+  return(cohortDefinitionSet)
+}
+
+addTemplateColumns <- function(cohortDefinitionSet) {
+  if (nrow(cohortDefinitionSet) > 0 & !hasTemplateDefinitions(cohortDefinitionSet)) {
+    cohortDefinitionSet$isTemplatedCohort <- 0
+  }
+
+  return(cohortDefinitionSet)
+}
+
 exportCohortDefinitionSet <- function(outputFolder, cohortDefinitionSet = NULL) {
   cohortDefinitions <- createEmptyResult("cg_cohort_definition")
   cohortSubsets <- createEmptyResult("cg_cohort_subset_definition")
+  cohortTemplates <- createEmptyResult("cg_cohort_template_definition")
+  cohortTemplateLink <- createEmptyResult("cg_cohort_template_link")
   if (!is.null(cohortDefinitionSet)) {
+    templateDefinitions <- getTemplateDefinitions(cohortDefinitionSet)
+    if (length(templateDefinitions) > 0) {
+      for (template in templateDefinitions) {
+        row <- data.frame(
+          templateDefinitionId = template$getChecksum(),
+          json = template$toJson() |> as.character(),
+          templateName = template$name,
+          templateSql = template$templateSql
+        )
+        cohortTemplates <- dplyr::bind_rows(cohortTemplates, row)
+        linkRows <- data.frame(
+          templateDefinitionId = template$getChecksum(),
+          cohortDefinitionId = template$references$cohortId
+        )
+        cohortTemplateLink <- dplyr::bind_rows(cohortTemplateLink, linkRows)
+      }
+      cohortDefinitionSet$isTemplatedCohort <- as.integer(cohortDefinitionSet$isTemplatedCohort)
+    } else {
+      cohortDefinitionSet <- cohortDefinitionSet |> addTemplateColumns()
+    }
+
     cdsCohortSubsets <- getSubsetDefinitions(cohortDefinitionSet)
     if (length(cdsCohortSubsets) > 0) {
       for (i in seq_along(cdsCohortSubsets)) {
-        cohortSubsets <- rbind(
+        cohortSubsets <- dplyr::bind_rows(
           cohortSubsets,
           data.frame(
             subsetDefinitionId = cdsCohortSubsets[[i]]$definitionId,
@@ -177,25 +202,9 @@ exportCohortDefinitionSet <- function(outputFolder, cohortDefinitionSet = NULL)
           )
         )
       }
+      cohortDefinitionSet$isSubset <- as.integer(cohortDefinitionSet$isSubset)
     } else {
-      # NOTE: In this case the cohortDefinitionSet has no subsets defined
-      # and so we need to add the additional columns that are defined
-      # in the function: addCohortSubsetDefinition. To do this,
-      # we'll construct a copy of the cohortDefinitionSet with a single
-      # subset to get the proper structure and filter it to the
-      # cohorts of interest.
-      cdsCopy <- cohortDefinitionSet %>%
-        addCohortSubsetDefinition(
-          cohortSubsetDefintion = createCohortSubsetDefinition(
-            definitionId = 1,
-            name = "empty",
-            subsetOperators = list(
-              createDemographicSubset()
-            )
-          )
-        ) %>%
-        dplyr::filter(.data$cohortId == cohortDefinitionSet$cohortId)
-      cohortDefinitionSet <- cdsCopy
+      cohortDefinitionSet <- cohortDefinitionSet |> addSubsetColumns()
     }
     # Massage and save the cohort definition set
     colsToRename <- c("cohortId", "cohortName", "sql", "json")
@@ -214,19 +223,57 @@ exportCohortDefinitionSet <- function(outputFolder, cohortDefinitionSet = NULL)
     x = cohortSubsets,
     file = file.path(outputFolder, "cg_cohort_subset_definition.csv")
   )
+
+  writeCsv(
+    x = cohortTemplates,
+    file = file.path(outputFolder, "cg_cohort_template_definition.csv")
+  )
+
+  writeCsv(
+    x = cohortTemplateLink,
+    file = file.path(outputFolder, "cg_cohort_template_link.csv")
+  )
 }
 
 createEmptyResult <- function(tableName) {
   columns <- readCsv(
     file = system.file("csv", "resultsDataModelSpecification.csv", package = "CohortGenerator")
-  ) %>%
-    dplyr::filter(.data$tableName == !!tableName) %>%
-    dplyr::pull(.data$columnName) %>%
-    SqlRender::snakeCaseToCamelCase()
-  result <- vector(length = length(columns))
-  names(result) <- columns
-  result <- tibble::as_tibble(t(result), name_repair = "check_unique")
+  ) |>
+    dplyr::filter(.data$tableName == !!tableName)
+
+  # Initialize an empty list to hold columns
+  resultList <- list()
+
+  # Loop through each column info to create a strongly typed empty column
+  for (i in seq_len(nrow(columns))) {
+    colName <- SqlRender::snakeCaseToCamelCase(columns$columnName[i])
+    dataType <- columns$dataType[i]
+
+    # Map data types to R types
+    colValue <- switch(tolower(dataType),
+      "bigint" = as.numeric(NA),
+      "varchar" = as.character(NA),
+      "text" = as.character(NA),
+      "int" = as.integer(NA),
+      "timestamp" = as.POSIXct(NA)
+    )
+
+    # Fallback when no data type is found
+    if (is.null(colValue)) {
+      warning(paste(colName, "has data type", tolower(dataType), "which was not converted."))
+      colValue <- as.character(NA)
+    }
+
+    # Assign to list
+    resultList[[colName]] <- colValue
+  }
+
+  # Convert list to tibble
+  result <- tibble::as_tibble(resultList)
+
+  # Ensure zero rows
   result <- result[FALSE, ]
+
   return(result)
 }
 
@@ -251,7 +298,9 @@ getColumnsToCensor <- function(tableName) {
 }
 
 enforceMinCellValue <- function(data, fieldName, minValues, silent = FALSE) {
-  toCensor <- !is.na(pull(data, fieldName)) & pull(data, fieldName) < minValues & pull(data, fieldName) != 0
+  toCensor <- !is.na(pull(data, fieldName)) &
+    pull(data, fieldName) < minValues &
+    pull(data, fieldName) != 0
   if (!silent) {
     percent <- round(100 * sum(toCensor) / nrow(data), 1)
     message(
