@@ -99,17 +99,6 @@ test_that("Call instatiateCohortSet with vector as cohortDefinitionSet parameter
   )
 })
 
-test_that("Call instatiateCohortSet with incremental = TRUE and no folder specified", {
-  expect_error(
-    generateCohortSet(
-      connectionDetails = connectionDetails,
-      cohortDefinitionSet = getCohortsForTest(cohorts),
-      incremental = TRUE
-    ),
-    message = "Must specify incrementalFolder"
-  )
-})
-
 # getInclusionStatistics ------
 test_that("Call getInclusionStatistics without connection or connectionDetails", {
   expect_error(getInclusionStatistics(),
@@ -127,8 +116,7 @@ test_that("Generate cohorts before creating cohort tables errors out", {
     cohortDatabaseSchema = "main",
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithStats,
-    incremental = FALSE,
-    incrementalFolder = file.path(outputFolder, "RecordKeeping")
+    incremental = FALSE
   ))
 })
 
@@ -146,15 +134,13 @@ test_that("Create cohorts with stats, Incremental = F, Gather Results", {
     cohortDatabaseSchema = "main",
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithStats,
-    incremental = FALSE,
-    incrementalFolder = file.path(outputFolder, "RecordKeeping")
+    incremental = FALSE
   )
   expect_equal(nrow(cohortsGenerated), nrow(cohortsWithStats))
   rm(cohortsWithStats)
 })
 
 test_that("Create cohorts with stats, Incremental = T", {
-  recordKeepingFolder <- file.path(outputFolder, "RecordKeeping")
   cohortTableNames <- getCohortTableNames(cohortTable = "genStatsInc")
   createCohortTables(
     connectionDetails = connectionDetails,
@@ -169,8 +155,7 @@ test_that("Create cohorts with stats, Incremental = T", {
     cohortDatabaseSchema = "main",
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithStats,
-    incremental = TRUE,
-    incrementalFolder = recordKeepingFolder
+    incremental = TRUE
   )
   # 2nd run using incremental mode to verify that all cohorts are created
   # but the return indicates that nothing new was generated
@@ -180,13 +165,12 @@ test_that("Create cohorts with stats, Incremental = T", {
     cohortDatabaseSchema = "main",
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithStats,
-    incremental = TRUE,
-    incrementalFolder = recordKeepingFolder
+    incremental = TRUE
   )
+
   expect_equal(nrow(cohortsGenerated), nrow(cohortsWithStats))
   expect_true(all(cohortsGenerated$generationStatus == "SKIPPED"))
   rm(cohortsWithStats)
-  unlink(recordKeepingFolder, recursive = TRUE)
 })
 
 test_that("Create cohorts without stats, Incremental = F", {
@@ -204,15 +188,13 @@ test_that("Create cohorts without stats, Incremental = F", {
     cohortDatabaseSchema = "main",
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithoutStats,
-    incremental = FALSE,
-    incrementalFolder = file.path(outputFolder, "RecordKeeping")
+    incremental = FALSE
   )
   expect_equal(nrow(cohortsGenerated), nrow(cohortsWithoutStats))
   rm(cohortsWithoutStats)
 })
 
 test_that("Create cohorts without stats, Incremental = T", {
-  recordKeepingFolder <- file.path(outputFolder, "RecordKeeping")
   cohortTableNames <- getCohortTableNames(cohortTable = "noStatsInc")
   createCohortTables(
     connectionDetails = connectionDetails,
@@ -227,8 +209,7 @@ test_that("Create cohorts without stats, Incremental = T", {
     cohortDatabaseSchema = "main",
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithoutStats,
-    incremental = TRUE,
-    incrementalFolder = recordKeepingFolder
+    incremental = TRUE
   )
   # Next run using incremental mode to verify that all cohorts are created
   # but the return indicates that nothing new was generated
@@ -238,11 +219,9 @@ test_that("Create cohorts without stats, Incremental = T", {
     cohortDatabaseSchema = "main",
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithoutStats,
-    incremental = TRUE,
-    incrementalFolder = recordKeepingFolder
+    incremental = TRUE
   )
   expect_equal(nrow(cohortsGenerated), nrow(cohortsWithoutStats))
-  unlink(recordKeepingFolder, recursive = TRUE)
 })
 
 test_that("Create cohorts with stopOnError = TRUE", {
@@ -309,7 +288,6 @@ test_that("Create cohorts with stopOnError = FALSE", {
 })
 
 test_that("Create cohorts with stopOnError = FALSE and incremental = TRUE", {
-  recordKeepingFolder <- file.path(outputFolder, "RecordKeeping")
   cohortTableNames <- getCohortTableNames(cohortTable = "stop_error_f_inc_t")
   createCohortTables(
     connectionDetails = connectionDetails,
@@ -334,8 +312,7 @@ test_that("Create cohorts with stopOnError = FALSE and incremental = TRUE", {
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithoutStats,
     stopOnError = FALSE,
-    incremental = TRUE,
-    incrementalFolder = recordKeepingFolder
+    incremental = TRUE
   )
   expect_equal(nrow(cohortsGenerated), nrow(cohortsWithoutStats))
   expect_equal(nrow(cohortsGenerated[cohortsGenerated$generationStatus == "FAILED", ]), 1)
@@ -356,13 +333,11 @@ test_that("Create cohorts with stopOnError = FALSE and incremental = TRUE", {
     cohortTableNames = cohortTableNames,
     cohortDefinitionSet = cohortsWithoutStats,
     stopOnError = FALSE,
-    incremental = TRUE,
-    incrementalFolder = recordKeepingFolder
+    incremental = TRUE
   )
   expect_equal(nrow(cohortsGenerated), nrow(cohortsWithoutStats))
   expect_equal(nrow(cohortsGenerated[cohortsGenerated$generationStatus == "COMPLETE", ]), 1)
   expect_equal(nrow(cohortsGenerated[cohortsGenerated$generationStatus == "SKIPPED", ]), 4)
-  unlink(recordKeepingFolder, recursive = TRUE)
   if (file.exists("errorReportSql.txt")) {
     unlink("errorReportSql.txt")
   }
